@@ -587,7 +587,8 @@ class Rickle(BaseRickle):
                                           load=load,
                                           args=args_list,
                                           imports=imports,
-                                          includes_self_reference=includes_self_reference)
+                                          includes_self_reference=includes_self_reference,
+                                          is_method=True)
                     else:
                         self.__dict__.update({k: v})
                     continue
@@ -798,6 +799,7 @@ class Rickle(BaseRickle):
                 else:
                     exec('import {}'.format(i), globals())
         suffix: str = uuid.uuid4().hex
+        # print("METHOD:", is_method)
 
         args_string = ""
         if args and isinstance(args, dict):
@@ -823,10 +825,11 @@ class Rickle(BaseRickle):
         elif args and isinstance(args, list):
             arg_list = ['self'] if is_method else list()
             arg_list.extend(args)
+            # print("ARG LIST", arg_list)
 
             args_string = ','.join(args)
             func_string = 'lambda {args_list}: {name}({args})'.format(
-                args_list=args_string,
+                args_list=','.join(arg_list),
                 args=','.join(arg_list),
                 name=name + suffix)
         else:
@@ -845,6 +848,10 @@ class Rickle(BaseRickle):
         _load += load.replace("\n", "\n  ")
         exec(_load, globals())
 
+        # print("LOADING: \n", _load)
+        # print("\nFUNC: \n", func_string)
+        # print("\n=======================================\n")
+
         if return_function:
             return eval(func_string)
 
